@@ -51,6 +51,8 @@ DATA_URLS = {
     "person_photo"          : DATA_URL + "/people/%(person_name)s/photo",
     "signals"               : DATA_URL + "/signals",
     "signal"                : DATA_URL + "/signals/%(signal_id)s",
+    "signallikes"           : DATA_URL + "/signals/%(signal_id)s/likes",
+    "signallike"            : DATA_URL + "/signals/%(signal_id)s/likes/%(user_id)s",
     "signal_hide"           : DATA_URL + "/signals/%(signal_id)s/hidden",
     "uploads"               : DATA_URL + "/uploads",
     "users"                 : DATA_URL + "/users",
