@@ -19,9 +19,8 @@ class FakeConfig(object):
 def resp(status, body, headers={}):
     r = requests.models.Response()
     r.status_code = status
-    r.content = body
     r.headers = headers
-    return r, r.content
+    return r, body
 
 class FakeServer(Socialtext):
     def __init__(self, **kwargs):
@@ -320,6 +319,15 @@ class FakeClient(SocialtextClient):
             'x-signal-hash':"103dcc89023428d82", 
         })
 
+    def get_data_signals_123_likes(self, **kw):
+        return resp(200, [dict(user_id=u["user_id"], best_full_name=u["best_full_name"]) for u in self.get_data_users()[1]])
+
+    def delete_data_signals_123_likes_username(self, **kw):
+        return resp(200, None)
+
+    def put_data_signals_123_likes_username(self, **kw):
+        return resp(204, None)
+
     #########
     # USERS #
     #########
